package BlankOnDev::Version;
use strict;
use warnings FATAL => 'all';

# Version :
our $VERSION = '0.1000';

# boidev.pl version :
our $boidev_ver = '0.1000';

# bzr2git.pl version :
our $bzr2git_ver = '0.1000';
1;
#__END__
#